

from django.utils.translation import ugettext as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from .models import  PresentationModel, PresentationAccordion, FieldPresentation



class AccordionPlugin(CMSPluginBase):
    model = PresentationAccordion
    name = _('Accordion presentation')
    #module = _('Accordion')
    render_template = 'accordion_presentation/accordion.html'
    allow_children = True
    child_classes = ['PresentationPlugin']
    
    def render(self, context, instance, placeholder):
        context.update({
            'accordion': instance,
            'placeholder': placeholder,
        })
        return context

class PresentationPlugin(CMSPluginBase):
    model = PresentationModel                # Model where data about this plugin is saved
    name = _("Presentation Plugin")                 # Name of the plugin
    render_template = "accordion_presentation/plugin.html"   # template to render the plugin with

    def render(self, context, instance, placeholder):
        context.update({'instance':instance,
                        'placeholder': placeholder,})
        return context


class FieldPlugin(CMSPluginBase):
    model = FieldPresentation
    name = _('Field accordion presentation')
    render_template = 'accordion_presentation/field.html'
    allow_children = False
    

plugin_pool.register_plugin(AccordionPlugin)
plugin_pool.register_plugin(PresentationPlugin) # register the plugin
plugin_pool.register_plugin(FieldPlugin)



from setuptools import setup, find_packages
setup(
    name='accordion_presentation',
    version='0.2.3',
    description='It is a simple horizontal accordion for django cms',
    long_description=open('README.rst').read(),
    author='Luisza',
    license = "GPLv2",
    author_email='luisza14@gmail.com',
    url='http://github.com/luisza/accordion_presentation',
    packages=find_packages(),
    keywords='tab django cms django-cms plugin',
    classifiers=[
    'Development Status :: 4 - Beta',
    'Environment :: Web Environment',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Framework :: Django',
    ],
    include_package_data=True,
    zip_safe=False,
    install_requires=open('requirements.txt').read().split('\n'),
)
